# -*- coding: utf-8 -*-
"""The test module for Hanzi Identifier."""

import unittest

import hanzidentifier


class TestIdentifyFunction(unittest.TestCase):

    def test_return_none(self):
        text = 'Hello my name is Thomas.'
        self.assertIsNone(hanzidentifier.identify(text))

    def test_return_simp(self):
        text = u'Thomas 说：你好！'
        self.assertEqual(hanzidentifier.identify(text), hanzidentifier.SIMP)

    def test_return_trad(self):
        text = u'Thomas 說：你好！'
        self.assertEqual(hanzidentifier.identify(text), hanzidentifier.TRAD)

    def test_return_either(self):
        text = u'你好！'
        self.assertEqual(hanzidentifier.identify(text), hanzidentifier.EITHER)

    def test_return_both(self):
        text = u'Country in simplified: 国. Country in traditional: 國'
        self.assertEqual(hanzidentifier.identify(text), hanzidentifier.BOTH)

if __name__ == '__main__':
    unittest.main()



"""
This file allows you to separately download large dictionary 
files for use with Mafan, if you would find it necessary.

These files can be rather large, so they don't come with the 
default mafan distribution.
"""
import os
import urllib2

from os.path import basename
from urlparse import urlsplit

def url2name(url):
    return basename(urlsplit(url)[2])


def download(url, localFileName = None, localDirName = None):
    """
    Utility function for downloading files from the web 
    and retaining the same filename.
    """
    localName = url2name(url)
    req = urllib2.Request(url)
    r = urllib2.urlopen(req)
    if r.info().has_key('Content-Disposition'):
        # If the response has Content-Disposition, we take file name from it
        localName = r.info()['Content-Disposition'].split('filename=')
        if len(localName) > 1:
          localName = localName[1]
          if localName[0] == '"' or localName[0] == "'":
              localName = localName[1:-1]
        else:
          localName = url2name(r.url)
    elif r.url != url: 
        # if we were redirected, the real file name we take from the final URL
        localName = url2name(r.url)
    if localFileName: 
        # we can force to save the file as specified name
        localName = localFileName
    if localDirName:
        # we can also put it in some custom directory
        if not os.path.exists(localDirName):
          os.makedirs(localDirName)
        localName = os.path.join(localDirName, localName)

    f = open(localName, 'wb')
    f.write(r.read())
    f.close()


def download_traditional_word_list():
  """
  Download Jieba big dictionary for splitting and classifying 
  both traditional and simplified Chinese texts.
  """

  url = 'https://raw.github.com/fxsjy/jieba/master/extra_dict/dict.txt.big'
  download(url, localDirName='data')

if __name__ == '__main__':
  confirm = raw_input("You are about to download all dictionary files. Could be up to 50MB in total. Are you sure?\n (y/n) ")
  if confirm == 'y' or confirm == 'yes':
      download_traditional_word_list()


"""
Convert a file to utf-8 (or any encoding you want, really)
"""

__author__ =  'Herman Schaaf'
__version__=  '0.3'

import os
import sys
import subprocess
import logging
import chardet

logging.basicConfig(level=logging.ERROR)

def convert(filename, new_filename=None, overwrite=False, to_encoding='utf-8', force=True):
  """ Convert file with crappy encoding to a new proper encoding (or vice versa if you wish).

  filename -- the name, partial path or full path of the file you want to encode to a new encoding
  new_filename -- (optional) the name of the new file to be generated using the new encoding
  overwrite -- if `new_filename` is omitted, set this to True to change the supplied file's 
               encoding and not bother creating a new file (be careful! loss of information is likely)
  to_encoding -- the name of the encoding you wish to convert to (utf-8 by default)
  force -- Encode even if the current file is already in the correct encoding.
  """
  logging.info('Opening file %s' % filename)
  f = open(filename)
  detection = chardet.detect(f.read())
  f.close()
  encoding = detection.get('encoding')
  confidence = detection.get('confidence')
  logging.info('I think it is %s with %.1f%% confidence' % (encoding, confidence*100.0))

  delete_original = bool(new_filename) == False and overwrite
  if not new_filename or new_filename == filename:
    # use the current filename, but add the encoding to the name (while keeping extension intact)
    base_name, ext = os.path.splitext(filename)
    new_filename = base_name + '_%s' % to_encoding + ext

  if not encoding.lower() == to_encoding.lower():
    logging.info('Converting to %s with iconv...' % to_encoding)
  else:
    logging.info('Already in correct encoding.')
    if force:
      logging.info('Going ahead anyway, because force == True (the force is strong with this one)')
    else:
      logging.warning('Stopping. Use force = True if you want to force the encoding.')
      return None

  # command example: iconv -f gb18030 -t utf-8 chs.srt -o chs-utf8.srt
  p = subprocess.Popen(['iconv', '-f', encoding, '-t', to_encoding+"//IGNORE", os.path.abspath(filename), '-o', os.path.abspath(new_filename)], shell=False, stdout=subprocess.PIPE, stdin = subprocess.PIPE, stderr=subprocess.STDOUT)
  retval = p.wait()

  if delete_original and os.path.isfile(new_filename):
    os.remove(filename)
    os.rename(new_filename, filename)
    new_filename = filename

  return new_filename


def detect(filename, include_confidence=False):
  """
  Detect the encoding of a file.

  Returns only the predicted current encoding as a string.

  If `include_confidence` is True, 
  Returns tuple containing: (str encoding, float confidence)
  """
  f = open(filename)
  detection = chardet.detect(f.read())
  f.close()
  encoding = detection.get('encoding')
  confidence = detection.get('confidence')
  if include_confidence:
    return (encoding, confidence)
  return encoding


from setuptools import setup
from distutils.core import Command
import os
import sys


class TestCommand(Command):
    description = "Run tests"
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        import subprocess
        errno = subprocess.call(['nosetests', '--debug=DEBUG', '-s'])
        raise SystemExit(errno)

setup(
    name='mafan',
    version='0.2.9',
    author='Herman Schaaf',
    author_email='herman@ironzebra.com',
    packages=['mafan', 'mafan.hanzidentifier', 'mafan.third_party'],
    scripts=['bin/convert.py'],
    url='https://github.com/hermanschaaf/mafan',
    license='LICENSE.txt',
    description='A toolbox for working with the Chinese language in Python',
    long_description=open('docs/README.md').read(),
    cmdclass={
        'test': TestCommand,
    },
    install_requires=[
        "jieba == 0.29",
        "argparse == 1.1",
        "chardet == 2.1.1",
        "wsgiref == 0.1.2",
    ],
)
